/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sqoop.security;

import org.apache.sqoop.common.ErrorCode;

public enum AuthenticationError implements ErrorCode {

  /** An unknown error has occurred. */
  AUTH_0000("An unknown error has occurred"),

  /** The system was not able to find Kerberos keytab in sqoop configuration. */
  AUTH_0001("Unable to find Kerberos keytab"),

  /** The system was not able to find Kerberos principal in sqoop configuration. */
  AUTH_0002("Unable to find Kerberos principal"),

  /** The system was not able to login using Kerberos keytab and principal in sqoop configuration. */
  AUTH_0003("Unable to login using Kerberos keytab and principal"),

  /** Invalid FileSystemAccess security mode {simple, Kerberos}. */
  AUTH_0004("Invalid FileSystemAccess security mode");

  private final String message;

  private AuthenticationError(String message) {
    this.message = message;
  }

  public String getCode() {
    return name();
  }

  public String getMessage() {
    return message;
  }
}
